searchData={"items":[{"type":"module","title":"AbnfParsec","doc":"Generates a parser from ABNF definition - text (`:abnf`) or file path (`:abnf_file`)\n\nAn entry rule can be defined by `:parse`. If defined, a `parse/1` function and a\n`parse!/1` function will be generated with the entry rule.\n\nBy default, every chunk defined by a rule is wrapped (in list) and tagged by the\nrulename. Use the options to `:untag`, `:unwrap` or both (`:unbox`).\n\nParsed chunks (rules) can be discarded `:ignore`.\n\nTransformations (`:map`, `:reduce`, `:replace`) can be applied by passing in a\n`:transform` map with keys being rulenames and values being 2-tuples of\ntransformation type (`:map`, `:reduce`, `:replace`), and mfa tuple (for `:map` and `reduce`)\nor a literal value (for `:replace`)\n\nExample usage:\n\n    defmodule JsonParser do\n      use AbnfParsec,\n        abnf_file: \"test/fixture/json.abnf\",\n        parse: :json_text,\n        transform: %{\n          \"string\" => {:reduce, {List, :to_string, []}},\n          \"int\" => [{:reduce, {List, :to_string, []}}, {:map, {String, :to_integer, []}}],\n          \"frac\" => {:reduce, {List, :to_string, []}},\n          \"null\" => {:replace, nil},\n          \"true\" => {:replace, true},\n          \"false\" => {:replace, false}\n        },\n        untag: [\"member\"],\n        unwrap: [\"int\", \"frac\"],\n        unbox: [\n          \"JSON-text\",\n          \"null\",\n          \"true\",\n          \"false\",\n          \"digit1-9\",\n          \"decimal-point\",\n          \"escape\",\n          \"unescaped\",\n          \"char\"\n        ],\n        ignore: [\n          \"name-separator\",\n          \"value-separator\",\n          \"quotation-mark\",\n          \"begin-object\",\n          \"end-object\",\n          \"begin-array\",\n          \"end-array\"\n        ]\n    end\n\n    json = ~s| {\"a\": {\"b\": 1.2, \"c\": [true]}, \"d\": null, \"e\": \"e\\te\"} |\n\n    JsonParser.json_text(json)\n    # or\n    JsonParser.parse(json)\n    # => {:ok, ...}\n    JsonParser.parse!(json)\n    # =>\n\n    [\n      object: [\n        [\n          string: [\"a\"],\n          value: [\n            object: [\n              [string: [\"b\"], value: [number: [int: 1, frac: \".2\"]]],\n              [string: [\"c\"], value: [array: [value: [true]]]]\n            ]\n          ]\n        ],\n        [string: [\"d\"], value: [nil]],\n        [string: [\"e\"], value: [string: [\"e\\te\"]]]\n      ]\n    ]","ref":"AbnfParsec.html"},{"type":"macro","title":"AbnfParsec.__using__/1","doc":"All rules by default are wrapped and tagged. See NimbleParsec for more details.\n\nOptions:\n\n  - `:abnf` (`binary`) - ABNF directly in string data\n  - `:abnf_file` (`binary`) - ABNF file path\n  - `:debug` (`boolean`) - whether to output generated parser code\n\n  - `:skip` (`rulenames`) - rules to be skipped when generating parser code\n    - so user can define their own parsec definition\n  - `:ignore` (`rulenames`) - rules to be discarded after being parsed\n  - `:untag` (`rulenames`) - rules to be wrapped only after being parsed\n  - `:unwrap` (`rulenames`) - rules to be tagged only after being parsed\n    - needs to be sure that there is only singular parsed entry\n  - `:unbox` (`rulenames`) - made up term, to both untag and unwrap\n  - `:transform` (`transformations`) - a map of `rulenames` to transformations\n    - `{:map, mfa}`\n    - `{:reduce, mfa}`\n    - `{:replace, val}`\n    - `{:post_traverse, mfa}`\n    - `{:pre_traverse, mfa}`\n  - `:parse` (`atom`) - described in module doc, needs to be an atom that is in\n    normalized form of its original string rulename","ref":"AbnfParsec.html#__using__/1"},{"type":"type","title":"AbnfParsec.rulename/0","doc":"","ref":"AbnfParsec.html#t:rulename/0"},{"type":"type","title":"AbnfParsec.rulenames/0","doc":"","ref":"AbnfParsec.html#t:rulenames/0"},{"type":"type","title":"AbnfParsec.transformation/0","doc":"","ref":"AbnfParsec.html#t:transformation/0"},{"type":"type","title":"AbnfParsec.transformations/0","doc":"","ref":"AbnfParsec.html#t:transformations/0"},{"type":"module","title":"AbnfParsec.Parser","doc":"Abnf Parser.","ref":"AbnfParsec.Parser.html"},{"type":"function","title":"AbnfParsec.Parser.alternation/2","doc":"Parses the given `binary` as alternation.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the alternation (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"AbnfParsec.Parser.html#alternation/2"},{"type":"function","title":"Options - AbnfParsec.Parser.alternation/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"AbnfParsec.Parser.html#alternation/2-options"},{"type":"function","title":"AbnfParsec.Parser.char_val/2","doc":"Parses the given `binary` as char_val.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the char_val (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"AbnfParsec.Parser.html#char_val/2"},{"type":"function","title":"Options - AbnfParsec.Parser.char_val/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"AbnfParsec.Parser.html#char_val/2-options"},{"type":"function","title":"AbnfParsec.Parser.comment/2","doc":"Parses the given `binary` as comment.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the comment (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"AbnfParsec.Parser.html#comment/2"},{"type":"function","title":"Options - AbnfParsec.Parser.comment/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"AbnfParsec.Parser.html#comment/2-options"},{"type":"function","title":"AbnfParsec.Parser.concatenation/2","doc":"Parses the given `binary` as concatenation.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the concatenation (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"AbnfParsec.Parser.html#concatenation/2"},{"type":"function","title":"Options - AbnfParsec.Parser.concatenation/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"AbnfParsec.Parser.html#concatenation/2-options"},{"type":"function","title":"AbnfParsec.Parser.core_rule/2","doc":"Parses the given `binary` as core_rule.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the core_rule (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"AbnfParsec.Parser.html#core_rule/2"},{"type":"function","title":"Options - AbnfParsec.Parser.core_rule/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"AbnfParsec.Parser.html#core_rule/2-options"},{"type":"function","title":"AbnfParsec.Parser.element/2","doc":"Parses the given `binary` as element.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the element (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"AbnfParsec.Parser.html#element/2"},{"type":"function","title":"Options - AbnfParsec.Parser.element/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"AbnfParsec.Parser.html#element/2-options"},{"type":"function","title":"AbnfParsec.Parser.exception/2","doc":"Extension: Used in RFC3501","ref":"AbnfParsec.Parser.html#exception/2"},{"type":"function","title":"AbnfParsec.Parser.group/2","doc":"Parses the given `binary` as group.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the group (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"AbnfParsec.Parser.html#group/2"},{"type":"function","title":"Options - AbnfParsec.Parser.group/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"AbnfParsec.Parser.html#group/2-options"},{"type":"function","title":"AbnfParsec.Parser.normalize/1","doc":"","ref":"AbnfParsec.Parser.html#normalize/1"},{"type":"function","title":"AbnfParsec.Parser.num_val/2","doc":"Parses the given `binary` as num_val.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the num_val (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"AbnfParsec.Parser.html#num_val/2"},{"type":"function","title":"Options - AbnfParsec.Parser.num_val/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"AbnfParsec.Parser.html#num_val/2-options"},{"type":"function","title":"AbnfParsec.Parser.option/2","doc":"Parses the given `binary` as option.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the option (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"AbnfParsec.Parser.html#option/2"},{"type":"function","title":"Options - AbnfParsec.Parser.option/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"AbnfParsec.Parser.html#option/2-options"},{"type":"function","title":"AbnfParsec.Parser.parse/1","doc":"","ref":"AbnfParsec.Parser.html#parse/1"},{"type":"function","title":"AbnfParsec.Parser.parse!/1","doc":"","ref":"AbnfParsec.Parser.html#parse!/1"},{"type":"function","title":"AbnfParsec.Parser.prose_val/2","doc":"Parses the given `binary` as prose_val.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the prose_val (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"AbnfParsec.Parser.html#prose_val/2"},{"type":"function","title":"Options - AbnfParsec.Parser.prose_val/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"AbnfParsec.Parser.html#prose_val/2-options"},{"type":"function","title":"AbnfParsec.Parser.repetition/2","doc":"Parses the given `binary` as repetition.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the repetition (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"AbnfParsec.Parser.html#repetition/2"},{"type":"function","title":"Options - AbnfParsec.Parser.repetition/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"AbnfParsec.Parser.html#repetition/2-options"},{"type":"function","title":"AbnfParsec.Parser.rule/2","doc":"Parses the given `binary` as rule.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the rule (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"AbnfParsec.Parser.html#rule/2"},{"type":"function","title":"Options - AbnfParsec.Parser.rule/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"AbnfParsec.Parser.html#rule/2-options"},{"type":"function","title":"AbnfParsec.Parser.rulelist/2","doc":"Parses the given `binary` as rulelist.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the rulelist (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"AbnfParsec.Parser.html#rulelist/2"},{"type":"function","title":"Options - AbnfParsec.Parser.rulelist/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"AbnfParsec.Parser.html#rulelist/2-options"},{"type":"function","title":"AbnfParsec.Parser.rulename/2","doc":"Parses the given `binary` as rulename.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the rulename (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"AbnfParsec.Parser.html#rulename/2"},{"type":"function","title":"Options - AbnfParsec.Parser.rulename/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"AbnfParsec.Parser.html#rulename/2-options"},{"type":"exception","title":"AbnfParsec.LeftoverTokenError","doc":"","ref":"AbnfParsec.LeftoverTokenError.html"},{"type":"exception","title":"AbnfParsec.UnexpectedTokenError","doc":"","ref":"AbnfParsec.UnexpectedTokenError.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}